==> vertigo-quarto-impl-0.6.2-sources.jar: io/vertigo/quarto/publisher/impl/MergerPlugin.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.quarto.publisher.impl;

import io.vertigo.core.component.Plugin;
import io.vertigo.quarto.publisher.PublisherFormat;
import io.vertigo.quarto.publisher.model.PublisherData;

import java.io.File;
import java.io.IOException;
import java.net.URL;

/**
 * Merger Plugin pour la fusion de documents.
 * 
 * @author adufranne
 */
public interface MergerPlugin extends Plugin {

	/**
	 * Point d'entrée du plugin.
	 * 
	 * @param modelFileURL Chemin vers le fichier model
	 * @param data Données à fusionner avec le model
	 * @return le File généré.
	 * @throws IOException en cas d'erreur de lecture ou d'écriture.
	 */
	File execute(final URL modelFileURL, final PublisherData data) throws IOException;

	/**
	 * @return Type de format géré par ce plugin
	 */
	PublisherFormat getPublisherFormat();

}

==> vertigo-quarto-impl-0.8.2-sources.jar: io/vertigo/quarto/publisher/impl/MergerPlugin.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.quarto.publisher.impl;

import io.vertigo.lang.Plugin;
import io.vertigo.quarto.publisher.PublisherFormat;
import io.vertigo.quarto.publisher.model.PublisherData;

import java.io.File;
import java.io.IOException;
import java.net.URL;

/**
 * Merger Plugin pour la fusion de documents.
 * 
 * @author adufranne
 */
public interface MergerPlugin extends Plugin {

	/**
	 * Point d'entrée du plugin.
	 * 
	 * @param modelFileURL Chemin vers le fichier model
	 * @param data Données à fusionner avec le model
	 * @return le File généré.
	 * @throws IOException en cas d'erreur de lecture ou d'écriture.
	 */
	File execute(final URL modelFileURL, final PublisherData data) throws IOException;

	/**
	 * @return Type de format géré par ce plugin
	 */
	PublisherFormat getPublisherFormat();

}
